## Ansættelseskontrakt

Mellem undertegnede

<company-name>Østfyns Vuggestuer</company-name>  
Skolevej 9, st., 8700 Horsens  
CVR-nr.: 29983455 (herefter kaldet virksomheden)

og

## Charlotte Olesen

Bøgevænget 3, 1. mf., 8632 Lemming (herefter kaldet medarbejderen)

indgås følgende ansættelseskontrakt:

<start-date>
## [SECTION-IDX]. Tiltrædelse

Medarbejderen tiltræder stillingen med virkning fra den 1. september 2024.
</start-date>

<title>
## [SECTION-IDX]. Stillingsbetegnelse

Medarbejderen ansættes som Pædagogmedhjælper.
</title>

<location>
## [SECTION-IDX]. Arbejdssted

Det primære arbejdssted er Skolevej 9, st., 8654 Bryrup.
</location>

## [SECTION-IDX]. Arbejdsopgaver

Medarbejderen skal varetage følgende primære opgaver:

- Daglig pædagogisk støtte til børn i alderen 0-3 år
- Deltagelse i leg, aktiviteter og måltider
- Medvirken ved udflugter
- Samarbejde med forældre og kolleger

Arbejdsopgaverne kan løbende justeres i forhold til institutionens behov.

<trial-period>
## [SECTION-IDX]. Prøvetid

Ansættelsen omfatter ikke en aftalt prøvetid.
</trial-period>

<salary>
## [SECTION-IDX]. Løn

Medarbejderen aflønnes med en månedsløn på kr. 26.000 brutto, svarende til kr. 312.000 årligt (før skat, pension og eventuelle lovpligtige bidrag). Lønnen udbetales månedsvis bagud til den anviste konto den sidste hverdag i måneden.
</salary>

<pension>
## [SECTION-IDX]. Pension

Der indbetales pensionsbidrag til PenSam. Virksomheden indbetaler 13% og medarbejderen 4% af alle faste løndele til pensionsordningen.
</pension>

<work-time>
## [SECTION-IDX]. Arbejdstid

Den ugentlige arbejdstid er 35 timer. Arbejdstiden placeres efter nærmere aftale inden for institutionens åbningstid. Frokostpausen er inkluderet i arbejdstiden.
</work-time>

<holiday>
## [SECTION-IDX]. Ferie

Medarbejderen har ret til ferie med løn i overensstemmelse med ferielovens regler. Særligt ferietillæg udbetales i henhold til lovgivningens bestemmelser.
</holiday>

<extra-holiday>
## [SECTION-IDX]. Feriefridage

Der ydes ikke ekstra feriefridage udover ferielovens bestemmelser.
</extra-holiday>

<training>
## [SECTION-IDX]. Efteruddannelse

Medarbejderen har mulighed for at deltage i relevant efter- og videreuddannelse efter nærmere aftale og under hensyn til institutionens behov samt gældende overenskomst mellem parterne.
</training>

<social-security>
## [SECTION-IDX]. Sociale sikringsbidrag

Virksomheden indbetaler alle påkrævede sociale sikringsbidrag, herunder ATP, barselsfond og øvrige relevante lovpligtige bidrag i overensstemmelse med dansk lovgivning.
</social-security>

<illness>
## [SECTION-IDX]. Sygdom

Såfremt medarbejderen ikke kan møde på arbejde på grund af sygdom, skal dette meddeles hurtigst muligt til institutionen efter de gældende retningslinjer.

Efter 3 dages sammenhængende sygdom kan virksomheden anmode om lægelig dokumentation. Udgifter hertil afholdes af virksomheden. Medarbejderen modtager sin normale løn under dokumenteret sygdom.
</illness>

<parental-leave>
## [SECTION-IDX]. Graviditet, barsel og forældreorlov

Medarbejderen er berettiget til orlov og løn under barsel i henhold til gældende barselslov og overenskomst. Der ydes fuld løn til mor i 4 uger før forventet fødsel samt i 14 uger efter fødsel. Medarbejderen har ret til 2 ugers orlov med løn som far/medmor inden for 14 uger efter fødsel.

Ved adoption gælder tilsvarende regler.

Medarbejderen har desuden ret til 2 fraværsdage med løn pr. kalenderår ved barns sygdom.
</parental-leave>

<termination>
## [SECTION-IDX]. Opsigelse

Ansættelsesforholdet kan af både medarbejderen og virksomheden opsiges med 30 dages varsel til udgangen af en kalendermåned. Opsigelsen skal være skriftlig og være modtageren i hænde senest den sidste hverdag i måneden. Funktionærlovens øvrige bestemmelser finder anvendelse, hvor det måtte være relevant.
</termination>

<collective-agreement>
## [SECTION-IDX]. Kollektiv overenskomst

Ansættelsesforholdet er omfattet af FOA overenskomsten.
</collective-agreement>

## [SECTION-IDX]. Tavshedspligt

Medarbejderen er under og efter ansættelsen forpligtet til at udvise tavshed overfor alle forhold, der vedrører institutionens drift, børns og forældres personlige oplysninger mv., jf. gældende lovgivning, samt de almindelige regler om loyalitet.

## [SECTION-IDX]. Retsgrundlag

Ansættelsesforholdet er underlagt dansk lovgivning. Hvor denne kontrakt eller overenskomsten ikke specifikt regulerer et forhold, finder funktionær- og ferielovens bestemmelser anvendelse.

Horsens, den 7. juni 2024

Medarbejderen _____________________________________

Virksomheden   _____________________________________